@@ -314,7 +314,7 @@ class RunTimeSandbox(object):
         Restarts the scope's sandbox using the specified docker image
 
         :param docker_image_name: name of the docker image to start
-        :returns: retruned value of restart_docker_container
+        :returns: returned value of restart_docker_container
         """
         if self.docker_repo:
             docker_image_name = '%s/%s' % (self.docker_repo,
@@ -717,7 +717,7 @@ class StorletInvocationProtocol(object):
             rc = SBus.send(self.storlet_pipe_path, dtg)
             if (rc < 0):
                 raise StorletRuntimeException('Failed to cancel task')
-            # TODO(takashi): Check the reponse here
+            # TODO(takashi): Check the response here
             os.read(read_fd, 10)
 
     def _invoke(self):
