@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import urllib
+from six.moves.urllib.parse import unquote
 from swift.common.internal_client import InternalClient
 from swift.common.swob import HTTPBadRequest, Response, Range
 from swift.common.utils import config_true_value
@@ -378,15 +378,29 @@ class StorletBaseHandler(object):
         for param in self.request.headers:
             if param.lower().startswith('x-storlet-parameter'):
                 keyvalue = self.request.headers[param]
-                keyvalue = urllib.unquote(keyvalue)
+                keyvalue = unquote(keyvalue)
                 key, value = keyvalue.split(':', 1)
                 parameters[key] = value
         self.request.params.update(parameters)
 
     def _set_metadata_in_headers(self, headers, user_metadata):
+        # _set_metadata_in_headers is for user metadata
+        # set by the storlet invocation. This metadata
+        # should be prefixed by 'X-Object-Meta' before
+        # we return things to Swift.
+        # Do not call this method with metadata headers
+        # coming from swift request or response.
         if user_metadata:
             for key, val in user_metadata.items():
-                headers['X-Object-Meta-%s' % key] = val
+                # TODO(kota_): we may need to discuss what type of special
+                # system metadata can be overwritten in the HTTP header and
+                # should encapsulate in StorletRequest/Response class
+                if key.lower() == 'content-type':
+                    # If and only if it's content-type, storlet app is able
+                    # to overwrite the header due to the application
+                    headers[key] = val
+                else:
+                    headers['X-Object-Meta-%s' % key] = val
 
     def _call_gateway(self, resp):
         """
@@ -402,7 +416,7 @@ class StorletBaseHandler(object):
         Apply storlet on response
 
         :param resp: swob.Response instance
-        :return: processed reponse
+        :return: processed response
         """
         sresp = self._call_gateway(resp)
 
