@@ -179,7 +179,7 @@ class TestStorletDockerGateway(unittest.TestCase):
         self.obj = 'object'
         self.sobj = 'storlet-1.0.jar'
 
-        # TODO(kota_): shoudl be 'storlet-internal-client.conf' actually
+        # TODO(kota_): should be 'storlet-internal-client.conf' actually
         ic_conf_path = os.path.join(self.tempdir,
                                     'storlet-proxy-server.conf')
         with open(ic_conf_path, 'w') as f:
@@ -438,7 +438,7 @@ use = egg:swift#catch_errors
         # prepare nested mock patch
         # SBus -> mock SBus.send() for container communication
         # os.read -> mock reading the file descriptor from container
-        # select.slect -> mock fd communication wich can be readable
+        # select.slect -> mock fd communication which can be readable
         @mock.patch('storlets.gateway.gateways.docker.runtime.SBus', MockSBus)
         @mock.patch('storlets.gateway.gateways.docker.runtime.os.read',
                     mock_read)
@@ -474,7 +474,7 @@ use = egg:swift#catch_errors
         expected_mock_writer_calls = len(extra_sources) + 1
         self.assertEqual(expected_mock_writer_calls,
                          len(called_fd_and_bodies))
-        self.assertEqual(called_fd_and_bodies[0][1], 'body')
+        self.assertEqual('body', called_fd_and_bodies[0][1])
         return called_fd_and_bodies
 
     def test_docker_gateway_communicate(self):
@@ -512,7 +512,7 @@ use = egg:swift#catch_errors
         extra_request = generate_extra_st_request()
         mock_calls = self._test_docker_gateway_communicate(
             extra_sources=[extra_request])
-        self.assertEqual(mock_calls[1][1], 'This is a response body')
+        self.assertEqual('This is a response body', mock_calls[1][1])
 
         # run all existing eventlet threads
         for app_iter in data_sources:
