@@ -29,7 +29,6 @@ from storlets.gateway.gateways.docker.runtime import RunTimeSandbox, \
     RunTimePaths, StorletInvocationProtocol
 from tests.unit import FakeLogger, with_tempdir
 from tests.unit.gateway.gateways import FakeFileManager
-from exceptions import AssertionError
 
 
 @contextmanager
@@ -117,7 +116,7 @@ class TestRuntimePaths(unittest.TestCase):
                 mock.patch('os.makedirs') as m, \
                 mock.patch('os.chmod') as c:
             self.paths.create_host_pipe_prefix()
-            self.assertEqual(m.call_count, 0)
+            self.assertEqual(0, m.call_count)
             cargs, ckwargs = c.call_args
             # Make sure about the target directory
             self.assertEqual(cargs[0], pipedir)
@@ -127,7 +126,7 @@ class TestRuntimePaths(unittest.TestCase):
                 mock.patch('os.makedirs') as m, \
                 mock.patch('os.chmod') as c:
             self.paths.create_host_pipe_prefix(),
-            self.assertEqual(m.call_count, 1)
+            self.assertEqual(1, m.call_count)
             # Make sure about the target directory
             margs, mkwargs = m.call_args
             self.assertEqual(margs[0], pipedir)
@@ -172,7 +171,7 @@ class TestRuntimePaths(unittest.TestCase):
                 self.paths.slog_path(self.storlet_id),
                 os.path.join(self.log_dir, self.scope,
                              self.storlet_id))
-            self.assertEqual(m.call_count, 0)
+            self.assertEqual(0, m.call_count)
 
         with mock.patch('os.path.exists', return_value=False), \
             mock.patch('os.makedirs') as m:
@@ -180,7 +179,7 @@ class TestRuntimePaths(unittest.TestCase):
                 self.paths.slog_path(self.storlet_id),
                 os.path.join(self.log_dir, self.scope,
                              self.storlet_id))
-            self.assertEqual(m.call_count, 1)
+            self.assertEqual(1, m.call_count)
 
     def test_get_host_storlet_cache_dir(self):
         self.assertEqual(
@@ -270,11 +269,11 @@ class TestRunTimeSandbox(unittest.TestCase):
     def test_parse_sandbox_factory_answer(self):
         status, msg = self.sbox._parse_sandbox_factory_answer('True:message')
         self.assertTrue(status)
-        self.assertEqual(msg, 'message')
+        self.assertEqual('message', msg)
 
         status, msg = self.sbox._parse_sandbox_factory_answer('False:message')
         self.assertFalse(status)
-        self.assertEqual(msg, 'message')
+        self.assertEqual('message', msg)
 
         with self.assertRaises(StorletRuntimeException):
             self.sbox._parse_sandbox_factory_answer('Foo')
@@ -286,11 +285,11 @@ class TestRunTimeSandbox(unittest.TestCase):
 
     def test_ping(self):
         with _mock_os_pipe(['True:OK']) as pipes, _mock_sbus(0):
-            self.assertEqual(self.sbox.ping(), 1)
+            self.assertEqual(1, self.sbox.ping())
             self._check_all_pipese_closed(pipes)
 
         with _mock_os_pipe(['False:ERROR']) as pipes, _mock_sbus(-1):
-            self.assertEqual(self.sbox.ping(), -1)
+            self.assertEqual(-1, self.sbox.ping())
             self._check_all_pipese_closed(pipes)
 
         with _mock_os_pipe(['Foo']) as pipes, _mock_sbus(0):
@@ -303,7 +302,7 @@ class TestRunTimeSandbox(unittest.TestCase):
             mock.patch('storlets.gateway.gateways.docker.runtime.'
                        'time.sleep') as _s:
             self.sbox.wait()
-            self.assertEqual(_s.call_count, 0)
+            self.assertEqual(0, _s.call_count)
             self._check_all_pipese_closed(pipes)
 
         with _mock_os_pipe(['False:ERROR', 'True:OK']) as pipes, \
@@ -311,7 +310,7 @@ class TestRunTimeSandbox(unittest.TestCase):
             mock.patch('storlets.gateway.gateways.docker.runtime.'
                        'time.sleep') as _s:
             self.sbox.wait()
-            self.assertEqual(_s.call_count, 1)
+            self.assertEqual(1, _s.call_count)
             self._check_all_pipese_closed(pipes)
 
         with _mock_os_pipe(['Foo']) as pipes, _mock_sbus(0), \
@@ -356,11 +355,11 @@ class TestRunTimeSandbox(unittest.TestCase):
         storlet_main = 'org.openstack.storlet.Storlet'
         dependencies = ['dep1', 'dep2']
         self.assertEqual(
-            self.sbox._get_storlet_classpath(storlet_main, storlet_id,
-                                             dependencies),
             '/home/swift/org.openstack.storlet.Storlet/Storlet.jar:'
             '/home/swift/org.openstack.storlet.Storlet/dep1:'
-            '/home/swift/org.openstack.storlet.Storlet/dep2')
+            '/home/swift/org.openstack.storlet.Storlet/dep2',
+            self.sbox._get_storlet_classpath(storlet_main, storlet_id,
+                                             dependencies),)
 
 
 class TestStorletInvocationProtocol(unittest.TestCase):
@@ -455,32 +454,32 @@ class TestStorletInvocationProtocol(unittest.TestCase):
             (None, TypeError), (-1, ValueError), ('blah', TypeError))
 
         for invalid_fd, expected_error in invalid_fds:
-            with mock.patch('os.close') as mock_close:
-                with self.assertRaises(expected_error):
-                    with self.protocol._open_writer(invalid_fd):
-                        pass
-                # writer attempts to close fd via os call
-                self.assertEqual(1, mock_close.call_count)
+            with self.assertRaises(expected_error):
+                with self.protocol._open_writer(invalid_fd):
+                    pass
 
     def _test_writer_with_exception(self, exception_cls):
-        mock_writer = mock.MagicMock()
-        with mock.patch('os.fdopen') as mock_fdopen, \
-                mock.patch('os.close') as mock_close:
-            mock_fdopen.return_value = mock_writer
-
-            def raise_in_the_context():
-                with self.protocol._open_writer(1):
-                    raise exception_cls()
+        pipes = [os.pipe()]
 
+        def raise_in_the_context():
+            with self.protocol._open_writer(pipes[0][1]):
+                raise exception_cls()
+        try:
             # writer context doesn't suppress any exception
             self.assertRaises(exception_cls, raise_in_the_context)
 
-        # sanity
-        self.assertEqual(1, mock_fdopen.call_count)
-        self.assertEqual(0, mock_close.call_count)
+            # since _open_writer closes the write fd, the os.close will fail as
+            # BadFileDescriptor
+            with self.assertRaises(OSError) as os_error:
+                os.close(pipes[0][1])
+            self.assertEqual(9, os_error.exception.errno)
 
-        # writer was closed
-        self.assertEqual(1, mock_writer.close.call_count)
+        finally:
+            for fd in pipes[0]:
+                try:
+                    os.close(fd)
+                except OSError:
+                    pass
 
     def test_writer_raise_while_in_writer_context(self):
         # basic storlet timeout
